# orchestral
#### Orchestrate and execute shell, async, and sync tasks.

[![PyPI version](https://img.shields.io/pypi/v/orchestral?color=blue)](https://pypi.org/project/orchestral/)
[![License](https://img.shields.io/github/license/adalundhe/orchestral)](https://github.com/adalundhe/orchestral/blob/main/LICENSE)
[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](https://github.com/adalundhe/orchestral/blob/main/CODE_OF_CONDUCT.md)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/orchestral?color=red)](https://pypi.org/project/orchestral/)


| Package     | orchestral                                                          |
| ----------- | -----------                                                         |
| Version     | 0.1.0                                                               |
| Download    | https://pypi.org/project/orchestral/                                | 
| Source      | https://github.com/adalundhe/orchestral                             |
| Keywords    | async, tasks, runner, graph, workflow, shell, jobs                  |

